use strict;
use warnings;

package Jifty::Plugin::EditInPlace;
use base qw/Jifty::Plugin/;

=head1 NAME

Jifty::Plugin::EditInPlace - Edit files via web browser

=cut

package HTML::Mason::Request::Jifty;

=head1 SYNOPSIS

In etc/config.yml

   Plugins:
     - EditInPlace: {}

=head1 DESCRIPTION

In admin interface you can edit mason files with your web browser

=head1 METHOD

=head2 fetch_comp

read mason file

=cut

sub fetch_comp {
    my $self = shift;
    my $comp = $self->SUPER::fetch_comp(@_);
    if (not $comp and  Jifty->config->framework('DevelMode') ) {
        my $comp_name = shift;
        $comp = $self->interp->make_component( 
                comp_source => 
                    "
                       <span id=\"create-component-$comp_name\">
<% Jifty->web->link(class => 'inline_create', label => 'Create $comp_name',  onclick => [ { element      => \"#create-component-$comp_name\", replace_with =>  '/__jifty/edit_inline/mason_component/$comp_name'  } ]) %>
                       </span> 
                    ");
            
            
    }
    return $comp;
}


=head1 AUTHORS

Jesse Vincent C<< <jesse@bestpractical.com> >>
Alex Vandiver C<< <alexmv@bestpractical.com> >>
Shawn M Moore C<< <sartak@bestpractical.com> >>

=head1 LICENSE

Jifty::Plugin::EditInPlace is Copyright 2006-2008 Best Practical Solutions, LLC.
This module is distributed under the same terms as Perl itself.

=cut

1;
